#!/usr/bin/env python3
# -*- coding: utf-8 -*-
"""
Created on Sun Apr  4 13:57:23 2021
Performs basic analysis of gridded climate data
@author: stefaan
"""

# %% imports

import xarray as xr
import pandas as pd
import numpy as np

# %% gridded analysis functions


def time_min(da):
    """Return the time when the minimum value of the input array occurs
    separately for every point in space"""
    return(da.idxmin(dim='time'))


def xr_np_time2yr(da):
    """takes in an xr dataarray whose .values is an np.datetime64 nd-array
    returns the year; years < 0 are NA'd"""
    da.values = da.values.astype('datetime64[Y]').astype(int) + 1970
    return(da.where(da > 0))


def xr_np_time2mon(da):
    """takes in an xr dataarray whose .values is an np.datetime64 nd-array
    returns the month"""
    da.values = da.values.astype('datetime64[M]').astype(int) % 12 + 1
    return(da)


def xr_np_time2day(da):
    """takes in an xr dataarray whose .values is an np.datetime64 nd-array
    returns the day of the month"""
    da.values = da.values - da.values.astype('datetime64[M]') + 1
    return (da)
